pub struct Signature {
pub(super) inner: BoxedUint,
}Expand description
RSASSA-PSS signatures as described in RFC8017  8.1.
Fields
inner: BoxedUintTrait Implementations
Sourceimpl<D> DigestVerifier<D, Signature> for VerifyingKey<D>
impl<D> DigestVerifier<D, Signature> for VerifyingKey<D>
Sourceimpl<D> PrehashVerifier<Signature> for VerifyingKey<D>where
D: Digest + FixedOutputReset,
impl<D> PrehashVerifier<Signature> for VerifyingKey<D>where
D: Digest + FixedOutputReset,
Sourceimpl<D> RandomizedDigestSigner<D, Signature> for BlindedSigningKey<D>
impl<D> RandomizedDigestSigner<D, Signature> for BlindedSigningKey<D>
Sourceimpl<D> RandomizedDigestSigner<D, Signature> for SigningKey<D>
impl<D> RandomizedDigestSigner<D, Signature> for SigningKey<D>
Sourceimpl<D> RandomizedMultipartSigner<Signature> for BlindedSigningKey<D>where
D: Digest + FixedOutputReset,
impl<D> RandomizedMultipartSigner<Signature> for BlindedSigningKey<D>where
D: Digest + FixedOutputReset,
Sourcefn try_multipart_sign_with_rng<R: TryCryptoRng + ?Sized>(
&self,
rng: &mut R,
msg: &[&[u8]],
) -> Result<Signature>
fn try_multipart_sign_with_rng<R: TryCryptoRng + ?Sized>( &self, rng: &mut R, msg: &[&[u8]], ) -> Result<Signature>
Equivalent of
RandomizedSigner::try_sign_with_rng() but the message is provided in
non-contiguous byte slices. Read moreSourcefn multipart_sign_with_rng<R>(&self, rng: &mut R, msg: &[&[u8]]) -> S
fn multipart_sign_with_rng<R>(&self, rng: &mut R, msg: &[&[u8]]) -> S
Equivalent of
RandomizedSigner::sign_with_rng() but the message is provided in
non-contiguous byte slices.Sourceimpl<D> RandomizedMultipartSigner<Signature> for SigningKey<D>
impl<D> RandomizedMultipartSigner<Signature> for SigningKey<D>
Sourcefn try_multipart_sign_with_rng<R: TryCryptoRng + ?Sized>(
&self,
rng: &mut R,
msg: &[&[u8]],
) -> Result<Signature>
fn try_multipart_sign_with_rng<R: TryCryptoRng + ?Sized>( &self, rng: &mut R, msg: &[&[u8]], ) -> Result<Signature>
Equivalent of
RandomizedSigner::try_sign_with_rng() but the message is provided in
non-contiguous byte slices. Read moreSourcefn multipart_sign_with_rng<R>(&self, rng: &mut R, msg: &[&[u8]]) -> S
fn multipart_sign_with_rng<R>(&self, rng: &mut R, msg: &[&[u8]]) -> S
Equivalent of
RandomizedSigner::sign_with_rng() but the message is provided in
non-contiguous byte slices.Sourceimpl<D> RandomizedPrehashSigner<Signature> for BlindedSigningKey<D>where
D: Digest + FixedOutputReset,
impl<D> RandomizedPrehashSigner<Signature> for BlindedSigningKey<D>where
D: Digest + FixedOutputReset,
Sourcefn sign_prehash_with_rng<R: TryCryptoRng + ?Sized>(
&self,
rng: &mut R,
prehash: &[u8],
) -> Result<Signature>
fn sign_prehash_with_rng<R: TryCryptoRng + ?Sized>( &self, rng: &mut R, prehash: &[u8], ) -> Result<Signature>
Attempt to sign the given message digest, returning a digital signature on success, or an
error if something went wrong. Read more
Sourceimpl<D> RandomizedPrehashSigner<Signature> for SigningKey<D>
impl<D> RandomizedPrehashSigner<Signature> for SigningKey<D>
Sourcefn sign_prehash_with_rng<R: TryCryptoRng + ?Sized>(
&self,
rng: &mut R,
prehash: &[u8],
) -> Result<Signature>
fn sign_prehash_with_rng<R: TryCryptoRng + ?Sized>( &self, rng: &mut R, prehash: &[u8], ) -> Result<Signature>
Attempt to sign the given message digest, returning a digital signature on success, or an
error if something went wrong. Read more
Sourceimpl<D> RandomizedSigner<Signature> for BlindedSigningKey<D>where
D: Digest + FixedOutputReset,
impl<D> RandomizedSigner<Signature> for BlindedSigningKey<D>where
D: Digest + FixedOutputReset,
Sourcefn try_sign_with_rng<R: TryCryptoRng + ?Sized>(
&self,
rng: &mut R,
msg: &[u8],
) -> Result<Signature>
fn try_sign_with_rng<R: TryCryptoRng + ?Sized>( &self, rng: &mut R, msg: &[u8], ) -> Result<Signature>
Attempt to sign the given message, returning a digital signature on success, or an error if
something went wrong. Read more
Sourceimpl<D> RandomizedSigner<Signature> for SigningKey<D>
impl<D> RandomizedSigner<Signature> for SigningKey<D>
Sourcefn try_sign_with_rng<R: TryCryptoRng + ?Sized>(
&self,
rng: &mut R,
msg: &[u8],
) -> Result<Signature>
fn try_sign_with_rng<R: TryCryptoRng + ?Sized>( &self, rng: &mut R, msg: &[u8], ) -> Result<Signature>
Attempt to sign the given message, returning a digital signature on success, or an error if
something went wrong. Read more
Sourceimpl SignatureBitStringEncoding for Signature
Available on crate feature encoding only.
impl SignatureBitStringEncoding for Signature
Available on crate feature
encoding only.Sourceimpl SignatureEncoding for Signature
impl SignatureEncoding for Signature
Sourceimpl<D> Verifier<Signature> for VerifyingKey<D>where
D: Digest + FixedOutputReset,
impl<D> Verifier<Signature> for VerifyingKey<D>where
D: Digest + FixedOutputReset,
impl Eq for Signature
impl StructuralPartialEq for Signature